@@ -8,7 +8,7 @@ def test_parallel_sort_float():
     x = np.random.random(size=1000)
 
     numpy_sort = np.sort(x)
-    test_sort = parallel_sort.parallel_sort(x)
+    test_sort = parallel_sort.sort(x)
 
     assert np.all(test_sort == numpy_sort)
 
@@ -17,7 +17,7 @@ def test_parallel_sort_int():
     x = np.random.randint(int(1e6), size=1000)
 
     numpy_sort = np.sort(x)
-    test_sort = parallel_sort.parallel_sort(x)
+    test_sort = parallel_sort.sort(x)
 
     assert np.all(test_sort == numpy_sort)
 
@@ -27,7 +27,7 @@ def test_parallel_inplace_sort_float():
     test_x = np.copy(x)
 
     x.sort()
-    parallel_sort.parallel_sort_inplace(test_x)
+    parallel_sort.sort_inplace(test_x)
 
     assert np.all(test_x == x)
 
@@ -37,7 +37,7 @@ def test_parallel_inplace_sort_int():
     test_x = x.copy()
 
     x.sort()
-    parallel_sort.parallel_sort_inplace(test_x)
+    parallel_sort.sort_inplace(test_x)
 
     assert np.all(test_x == x)
 
@@ -46,7 +46,7 @@ def test_parallel_argsort_float():
     x = np.random.random(size=1000)
 
     numpy_indices = np.argsort(x)
-    test_indices = parallel_sort.parallel_argsort(x)
+    test_indices = parallel_sort.argsort(x)
 
     assert np.all(test_indices == numpy_indices)
 
@@ -55,6 +55,6 @@ def test_parallel_argsort_int():
     x = np.random.randint(int(1e6), size=1000)
 
     numpy_indices = np.argsort(x)
-    test_indices = parallel_sort.parallel_argsort(x)
+    test_indices = parallel_sort.argsort(x)
 
     assert np.all(test_indices == numpy_indices)
